require "logger"
require "logger/logging"

module FTest
  autoload :Assert, "ftest/assert"
  autoload :BacktraceFilter, "ftest/backtrace_filter"
  autoload :ColoredLogger, "ftest/colored_logger"
  autoload :Config, "ftest/config"
  autoload :CLI, "ftest/cli"
  autoload :Runner, "ftest/runner"
  autoload :Util, "ftest/util"

  # FTest can be included in scripts as a mixin, e.g.
  #
  # require "ftest"
  # include FTest
  #
  # logger.info "hi"
  # assert true
  #
  # You can also require "ftest/script" to automatically include FTest
  def logger
    Config.logger
  end

  # Describe, context, it, and specify can help break up a larger test script
  # into chunks. Blocks are run # immediately; this is cosmetic enhancement
  # that also enables some degree of compatibility with other frameworks.
  %i(context describe it specify).each do |method_name|
    define_method method_name do |msg, &blk|
      blk.() if blk
    end
  end

  def self.included target
    Assert::Syntax.infect target
  end
end
